@@ -8,15 +8,15 @@ CleanCSV =
             for (FixString in c(", ", " ,", "\t,", ",\t")) {
               FindReplace(ThisFile, FixString, ",")
             }
-            message("Done.")
+            .Done() 
           }  # end ThisFile exists condition
               else {
-            warning("The specified file does not exist.\n")
+            .FileDoesNotExist()
           }
         }  # end for loop for files
       }  # end interactive ondition
           else {
-        warning("This function is meant for use in interactive mode only.\n")
+        .InteractiveOnly()
       }
       return(invisible(NULL))
     }
