@@ -10,12 +10,11 @@ ResetDefaults =
         PrefSettings =
             file.path(getOption("BrailleR.Folder"), "BrailleROptions")
         file.copy(DefSettings, PrefSettings, overwrite = TRUE)
-        message(
-            "You have reset all preferences to the original package defaults.\n")
+        .OriginalDefaults()
         if (Local) file.remove("BrailleROptions")
         devtools::reload("BrailleR")
       } else {
-        warning("This function is meant for use in interactive mode only.\n")
+        .InteractiveOnly()
       }
       return(invisible(NULL))
     }
@@ -26,14 +25,13 @@ ChooseEmbosser =
         Embosser = "none", Permanent = interactive(), Local = interactive()) {
       if (is.character(Embosser)) {
         options(BrailleR.Embosser = Embosser)
-        message(
-            "The BrailleR.Embosser option has been updated to ", Embosser, ".")
+        .OptionUpdated("Embosser", Embosser)
         if (Permanent) {
           Prefs = paste0(getOption("BrailleR.Folder"), "BrailleROptions")
           OpSet = as.data.frame(read.dcf(Prefs, all = TRUE))
           OpSet$BrailleR.Embosser = Embosser
           write.dcf(OpSet, file = Prefs)
-          message("and has overwritten the setting for all folders.")
+          .OptionPermanent()
         }
         if (Local) {
           Prefs = "BrailleROptions"
@@ -42,11 +40,10 @@ ChooseEmbosser =
           }
           OpSet$BrailleR.Embosser = Embosser
           write.dcf(OpSet, file = Prefs)
-          message(
-              "The new setting will remain in effect next time you load the BrailleR package in this directory.")
+          .OptionLocal()
         }
       } else {
-        warning("A text string was expected. No action taken.\n")
+        .ExpectingText()
       }
       return(invisible(NULL))
     }
@@ -61,14 +58,13 @@ ChooseSlideStyle =
               "The file", css,
               "is not in the css folder of the BrailleR package.\nPlease put it there before re-issuing this command.\n")
         } else {
-          message(
-              "The BrailleR.SlideStyle option has been updated to ", css, ".")
+          .OptionUpdated("SlideStyle", css)
           if (Permanent) {
             Prefs = paste0(getOption("BrailleR.Folder"), "BrailleROptions")
             OpSet = as.data.frame(read.dcf(Prefs, all = TRUE))
             OpSet$BrailleR.SlideStyle = css
             write.dcf(OpSet, file = Prefs)
-            message("and has overwritten the setting for all folders.")
+            .OptionPermanent()
           }
           if (Local) {
             Prefs = "BrailleROptions"
@@ -77,12 +73,11 @@ ChooseSlideStyle =
             }
             OpSet$BrailleR.SlideStyle = css
             write.dcf(OpSet, file = Prefs)
-            message(
-                "The new setting will remain in effect next time you load the BrailleR package in this directory.")
+            .OptionLocal()
           }
         }
       } else {
-        warning("A text string was expected. No action taken.\n")
+        .ExpectingText()
       }
       return(invisible(NULL))
     }
@@ -97,13 +92,13 @@ ChooseStyle =
               "The file", css,
               "is not in the css folder of the BrailleR package.\nPlease put it there before re-issuing this command.\n")
         } else {
-          message("The BrailleR.Style option has been updated to ", css, ".")
+          .OptionUpdated("Style", css)
           if (Permanent) {
             Prefs = paste0(getOption("BrailleR.Folder"), "BrailleROptions")
             OpSet = as.data.frame(read.dcf(Prefs, all = TRUE))
             OpSet$BrailleR.Style = css
             write.dcf(OpSet, file = Prefs)
-            message("and has overwritten the setting for all folders.")
+            .OptionPermanent()
           }
           if (Local) {
             Prefs = "BrailleROptions"
@@ -112,12 +107,11 @@ ChooseStyle =
             }
             OpSet$BrailleR.Style = css
             write.dcf(OpSet, file = Prefs)
-            message(
-                "The new setting will remain in effect next time you load the BrailleR package in this directory.")
+            .OptionLocal()
           }
         }
       } else {
-        warning("A text string was expected. No action taken.\n")
+        .ExpectingText()
       }
       return(invisible(NULL))
     }
@@ -128,13 +122,13 @@ SetAuthor =
         name = "BrailleR", Permanent = interactive(), Local = interactive()) {
       if (is.character(name)) {
         options(BrailleR.Author = name)
-        message("The BrailleR.Author option has been updated to ", name, ".")
+        .OptionUpdated("Author", name)
         if (Permanent) {
           Prefs = paste0(getOption("BrailleR.Folder"), "BrailleROptions")
           OpSet = as.data.frame(read.dcf(Prefs, all = TRUE))
           OpSet$BrailleR.Author = name
           write.dcf(OpSet, file = Prefs)
-          message("and has overwritten the setting for all folders.")
+          .OptionPermanent()
         }
         if (Local) {
           Prefs = "BrailleROptions"
@@ -143,11 +137,10 @@ SetAuthor =
           }
           OpSet$BrailleR.Author = name
           write.dcf(OpSet, file = Prefs)
-          message(
-              "The new setting will remain in effect next time you load the BrailleR package in this directory.")
+          .OptionLocal()
         }
       } else {
-        warning("A text string was expected. No action taken.\n")
+        .ExpectingText()
       }
       return(invisible(NULL))
     }
@@ -157,15 +150,13 @@ SetBRLPointSize =
     function(pt, Permanent = FALSE, Local = interactive()) {
       if ((10 < pt) & (pt < 40)) {
         options(BrailleR.BRLPointSize = pt)
-        message(
-            "The BrailleR.BRLPointSize option for the braille font has been changed to ",
-            pt, " inches.")
+        .OptionUpdated("BRLPointSize (for the braille font)", paste0(pt, " inches"))
         if (Permanent) {
           Prefs = paste0(getOption("BrailleR.Folder"), "BrailleROptions")
           OpSet = as.data.frame(read.dcf(Prefs, all = TRUE))
           OpSet$BrailleR.BRLPointSize = pt
           write.dcf(OpSet, file = Prefs)
-          message("and has overwritten the setting for all folders.")
+          .OptionPermanent()
         }
         if (Local) {
           Prefs = "BrailleROptions"
@@ -174,12 +165,10 @@ SetBRLPointSize =
           }
           OpSet$BrailleR.BRLPointSize = pt
           write.dcf(OpSet, file = Prefs)
-          message(
-              "The new setting will remain in effect next time you load the BrailleR package in this directory.")
+          .OptionLocal()
         }
       } else {
-        warning(
-            "The point size must be between 10 and 40 . \nNo change has been made to this setting.\n")
+        .NoChangeWarning("The point size must be between 10 and 40 .")
       }
       return(invisible(NULL))
     }
@@ -190,14 +179,13 @@ SetLanguage =
         Language = "en_us", Permanent = interactive(), Local = interactive()) {
       if (is.character(Language)) {
         options(BrailleR.Language = Language)
-        message(
-            "The BrailleR.Language option has been updated to ", Language, ".")
+        .OptionUpdated("Language", Language)
         if (Permanent) {
           Prefs = paste0(getOption("BrailleR.Folder"), "BrailleROptions")
           OpSet = as.data.frame(read.dcf(Prefs, all = TRUE))
           OpSet$BrailleR.Language = Language
           write.dcf(OpSet, file = Prefs)
-          message("and has overwritten the setting for all folders.")
+          .OptionPermanent()
         }
         if (Local) {
           Prefs = "BrailleROptions"
@@ -206,11 +194,10 @@ SetLanguage =
           }
           OpSet$BrailleR.Language = Language
           write.dcf(OpSet, file = Prefs)
-          message(
-              "The new setting will remain in effect next time you load the BrailleR package in this directory.")
+          .OptionLocal()
         }
       } else {
-        warning("A text string was expected. No action taken.\n")
+        .ExpectingText()
       }
       return(invisible(NULL))
     }
@@ -221,15 +208,14 @@ SetMakeUpper =
       Upper = as.logical(Upper)
       if (is.logical(Upper)) {
         options(BrailleR.MakeUpper = Upper)
-        message(
-            "The BrailleR.MakeUpper option for capitalising the initial letter of variable names has been changed to ",
-            Upper, ".")
+        .UpdatedSettingMSG(What="BrailleR.MakeUpper option for capitalising the initial letter of variable names", To=Upper) 
+
         if (Permanent) {
           Prefs = paste0(getOption("BrailleR.Folder"), "BrailleROptions")
           OpSet = as.data.frame(read.dcf(Prefs, all = TRUE))
           OpSet$BrailleR.MakeUpper = Upper
           write.dcf(OpSet, file = Prefs)
-          message("and has overwritten the setting for all folders.")
+          .OptionPermanent()
         }
         if (Local) {
           Prefs = "BrailleROptions"
@@ -238,12 +224,10 @@ SetMakeUpper =
           }
           OpSet$BrailleR.MakeUpper = Upper
           write.dcf(OpSet, file = Prefs)
-          message(
-              "The new setting will remain in effect next time you load the BrailleR package in this directory.")
+          .OptionLocal()
         }
       } else {
-        warning(
-            "The option must be either TRUE or FALSE.\nNo change has been made to this setting.\n")
+        .NoChangeWarning()
       }
       return(invisible(NULL))
     }
@@ -252,15 +236,13 @@ SetPaperHeight =
     function(Inches, Permanent = FALSE, Local = interactive()) {
       if ((5 < Inches) & (Inches < 14)) {
         options(BrailleR.PaperHeight = Inches)
-        message(
-            "The BrailleR.PaperHeight option for the height of the embossed images has been changed to ",
-            Inches, " inches.")
+        .UpdatedSettingMSG(What = "BrailleR.PaperHeight option for the height of the embossed images", To=paste(Inches, "inches"))
         if (Permanent) {
           Prefs = paste0(getOption("BrailleR.Folder"), "BrailleROptions")
           OpSet = as.data.frame(read.dcf(Prefs, all = TRUE))
           OpSet$BrailleR.PaperHeight = Inches
           write.dcf(OpSet, file = Prefs)
-          message("and has overwritten the setting for all folders.")
+          .OptionPermanent()
         }
         if (Local) {
           Prefs = "BrailleROptions"
@@ -269,12 +251,10 @@ SetPaperHeight =
           }
           OpSet$BrailleR.PaperHeight = Inches
           write.dcf(OpSet, file = Prefs)
-          message(
-              "The new setting will remain in effect next time you load the BrailleR package in this directory.")
+          .OptionLocal()
         }
       } else {
-        warning(
-            "The height must be between 5 and 14 inches. \nNo change has been made to this setting.\n")
+        .NoChangeWarning("The height must be between 5 and 14 inches.")
       }
       return(invisible(NULL))
     }
@@ -283,15 +263,13 @@ SetPaperWidth =
     function(Inches, Permanent = FALSE, Local = interactive()) {
       if ((5 < Inches) & (Inches < 14)) {
         options(BrailleR.PaperWidth = Inches)
-        message(
-            "The BrailleR.PaperWidth option for the width of the embossed images has been changed to ",
-            Inches, " inches.")
+        .UpdatedSettingMSG(What="BrailleR.PaperWidth option for the width of the embossed images", To=paste(Inches, "inches"))
         if (Permanent) {
           Prefs = paste0(getOption("BrailleR.Folder"), "BrailleROptions")
           OpSet = as.data.frame(read.dcf(Prefs, all = TRUE))
           OpSet$BrailleR.PaperWidth = Inches
           write.dcf(OpSet, file = Prefs)
-          message("and has overwritten the setting for all folders.")
+          .OptionPermanent()
         }
         if (Local) {
           Prefs = "BrailleROptions"
@@ -300,12 +278,10 @@ SetPaperWidth =
           }
           OpSet$BrailleR.PaperWidth = Inches
           write.dcf(OpSet, file = Prefs)
-          message(
-              "The new setting will remain in effect next time you load the BrailleR package in this directory.")
+          .OptionLocal()
         }
       } else {
-        warning(
-            "The width must be between 5 and 14 inches. \nNo change has been made to this setting.\n")
+        .NoChangeWarning("The width must be between 5 and 14 inches.")
       }
       return(invisible(NULL))
     }
@@ -317,15 +293,13 @@ SetPValDigits =
       digits = as.integer(digits)
       if (digits > 1) {
         options(BrailleR.PValDigits = digits)
-        message(
-            "The BrailleR.PValDigits option for the number of decimal places to display for p values has been changed to ",
-            digits, ".")
+        .UpdatedSettingMSG(What="BrailleR.PValDigits option for the number of decimal places to display for p values", To=digits)
         if (Permanent) {
           Prefs = paste0(getOption("BrailleR.Folder"), "BrailleROptions")
           OpSet = as.data.frame(read.dcf(Prefs, all = TRUE))
           OpSet$BrailleR.PValDigits = digits
           write.dcf(OpSet, file = Prefs)
-          message("and has overwritten the setting for all folders.")
+          .OptionPermanent()
         }
         if (Local) {
           Prefs = "BrailleROptions"
@@ -334,12 +308,10 @@ SetPValDigits =
           }
           OpSet$BrailleR.PValDigits = digits
           write.dcf(OpSet, file = Prefs)
-          message(
-              "The new setting will remain in effect next time you load the BrailleR package in this directory.")
+          .OptionLocal()
         }
       } else {
-        warning(
-            "The number of digits must be an integer greater than one.\nNo change has been made to this setting.\n")
+        .NoChangeWarning("The number of digits must be an integer greater than one")
       }
       return(invisible(NULL))
     }
@@ -348,15 +320,13 @@ SetSigLevel =
     function(alpha, Permanent = interactive(), Local = interactive()) {
       if ((0 < alpha) & (alpha < 1)) {
         options(BrailleR.SigLevel = alpha)
-        message(
-            "The BrailleR.SigLevel option for the level of alpha has been changed to ",
-            alpha, ".")
+        .UpdatedSettingMSG("BrailleR.SigLevel option for the level of alpha",To=alpha)
         if (Permanent) {
           Prefs = paste0(getOption("BrailleR.Folder"), "BrailleROptions")
           OpSet = as.data.frame(read.dcf(Prefs, all = TRUE))
           OpSet$BrailleR.SigLevel = alpha
           write.dcf(OpSet, file = Prefs)
-          message("and has overwritten the setting for all folders.")
+          .OptionPermanent()
         }
         if (Local) {
           Prefs = "BrailleROptions"
@@ -365,12 +335,10 @@ SetSigLevel =
           }
           OpSet$BrailleR.SigLevel = alpha
           write.dcf(OpSet, file = Prefs)
-          message(
-              "The new setting will remain in effect next time you load the BrailleR package in this directory.")
+          .OptionLocal()
         }
       } else {
-        warning(
-            "The level of alpha must be between 0 and 1. \nNo change has been made to this setting.\n")
+        .NoChangeWarning("The level of alpha must be between 0 and 1.")
       }
       return(invisible(NULL))
     }
@@ -380,43 +348,58 @@ SetSigLevel =
 GoSighted =
     function() {
       options(BrailleR.VI = FALSE)
-      message(
-          "By going sighted, you have turned off the automatic generation of text descriptions of graphs.\n")
+      .GoSightedMSG()
       return(invisible(NULL))
     }
 
 GoBlind =
     function() {
       options(BrailleR.VI = TRUE)
-      message(
-          "By going blind, you have turned on the automatic generation of text descriptions of graphs.\n")
+      .GoBlindMSG()
       return(invisible(NULL))
     }
 
+GoAdvanced =
+    function() {
+      options(BrailleR.Advanced = TRUE)
+      .GoAdvancedMSG()
+      return(invisible(NULL))
+    }
+
+
+GoNovice =
+    function() {
+      options(BrailleR.Advanced = FALSE)
+      .GoNoviceMSG()
+      return(invisible(NULL))
+    }
+
+
+
 ViewOn = function() {
            options(BrailleR.View = TRUE)
-           message("You have turned the automatic opening of html pages on.\n")
+           .ViewOnMSG()
            return(invisible(NULL))
          }
 
 ViewOff =
     function() {
       options(BrailleR.View = FALSE)
-      message("You have turned the automatic opening of html pages off.\n\n")
+      .ViewOffMSG()
       return(invisible(NULL))
     }
 
 LatexOn =
     function() {
       options(BrailleR.Latex = TRUE)
-      message("You have turned the automatic generation of LaTeX tables on.\n")
+      .LatexOnMSG()
       return(invisible(NULL))
     }
 
 LatexOff =
     function() {
       options(BrailleR.Latex = FALSE)
-      message("You have turned the automatic generation of LaTeX tables off.\n")
+      .LatexOffMSG()
       return(invisible(NULL))
     }
 
