@@ -6,11 +6,8 @@ for(i in FileList){
 Outfile = sub(paste0(".", intype), paste0(".", outtype),  i)
 if(file.mtime(i) > file.mtime(Outfile)| !file.exists(Outfile)) {
 shell(paste0('pandoc -s "', i, '" -o "', Outfile, '"'))
-message(paste("File", i, "converted to", Outfile))
+.FileUpdated(file=Outfile, where="in your current working directory.")
 }
 }
-
-
-
 return(invisible(TRUE))
 }
