@@ -2,7 +2,7 @@ ProcessAllRmd = function(dir =".", method = "render"){
       if (dir.exists(dir)) {
         FileSet = list.files(dir, pattern="\\.Rmd$", full.names=TRUE) 
         }
-        else stop("Specified folder does not exist.\n")
+        else {.MissingFolder()}
 .ProcessAll(dir = dir, method = method, FileSet, Extension=".Rmd")
       return(invisible(NULL))
 }
@@ -11,7 +11,7 @@ ProcessAllMd = function(dir ="."){
       if (dir.exists(dir)) {
         FileSet = list.files(dir, pattern="\\.md$", full.names=TRUE) 
         }
-        else stop("Specified folder does not exist.\n")
+        else {.MissingFolder()}
 .ProcessAll(dir = dir, FileSet = FileSet, Extension=".md")
       return(invisible(NULL))
 }
@@ -27,7 +27,7 @@ RemoveBOM(i)
       else if(method=="knit2html"){
           knitr::knit2html(i)
           }
-      else {stop("Specified method is not yet available.\n")}
+      else{.MissingMethod()} 
 }
 }
       return(invisible(NULL))
