@@ -1,3 +1,22 @@
+### Internal functions for base R plots
+
+.getGraphName = function(graph, titlePreamble = "With the title:", noTitleMessage="With no title") {
+  if (length(graph$main) > 0) {
+    if (nchar(gsub(" ", "",graph$main, fixed=T)) != 0) {
+      paste(titlePreamble,graph$main)
+    } else {
+      noTitleMessage
+    }
+    
+  } else if (nchar(graph$ExtraArgs$main) > 0) {
+    paste(titlePreamble,graph$ExtraArgs$main)
+  } else {
+    noTitleMessage
+  }
+}
+
+
+###VI methods
 
 VI = function(x, Describe=FALSE, ...) {
        UseMethod("VI")
@@ -11,8 +30,7 @@ return(invisible(x))
 
 VI.default =
     function(x, Describe=FALSE, ...) {
-      message("There is no specific method written for  this type of object.\n")
-      message("You might try to use the print() function on the object or the str() command to investigate its contents.\n")
+      .NoVIMethod()
       print(x)
     }
 
@@ -23,11 +41,10 @@ VI.boxplot =
 x=Augment(x)
       cat(paste0(
               'This graph has ', x$Boxplots, ' printed ', x$VertHorz,
-              '\n', ifelse(length(x$ExtraArgs$main) > 0, 'with the title: ',
-                           'but has no title'), x$ExtraArgs$main, '\n',
-              ifelse(length(x$ExtraArgs$xlab) > 0, InQuotes(x$ExtraArgs$xlab), 'No label'),
+              '\n', .getGraphName(x), '\n',
+              .ifelse(length(x$ExtraArgs$xlab) > 0, InQuotes(x$ExtraArgs$xlab), 'No label'),
               ' appears on the x-axis.\n',
-              ifelse(length(x$ExtraArgs$ylab) > 0, paste0('"', x$ExtraArgs$ylab, '"'), 'No label'),
+              .ifelse(length(x$ExtraArgs$ylab) > 0, paste0('"', x$ExtraArgs$ylab, '"'), 'No label'),
               ' appears on the y-axis.\n'))
       if (x$horizontal) {
         cat("Tick marks for the x-axis are at:", .GetAxisTicks(x$par$xaxp), "\n")
@@ -47,13 +64,13 @@ x=Augment(x)
         BoxLength = x$stats[4, i] - x$stats[2, i]
         cat('The median,', x$stats[3, i], 'is',
             round(100 * (x$stats[3, i] - x$stats[2, i]) / BoxLength, 0),
-            '% from the', ifelse(x$horizontal, 'left', 'lower'),
-            'end of the box to the', ifelse(x$horizontal, 'right', 'upper'),
+            '% from the', .ifelse(x$horizontal, 'left', 'lower'),
+            'end of the box to the', .ifelse(x$horizontal, 'right', 'upper'),
             'end.\n')
-        cat('The', ifelse(x$horizontal, 'right', 'upper'), 'whisker is',
+        cat('The', .ifelse(x$horizontal, 'right', 'upper'), 'whisker is',
             round((x$stats[5, i] -
                    x$stats[4, i]) / (x$stats[2, i] - x$stats[1, i]), 2),
-            'times the length of the', ifelse(x$horizontal, 'left', 'lower'),
+            'times the length of the', .ifelse(x$horizontal, 'left', 'lower'),
             'whisker.\n')
       }
       cat('\n')
@@ -82,15 +99,13 @@ VI.dotplot =
       Cuts = seq(MinVal, MaxVal, (MaxVal - MinVal) / Bins)
       # now do the description bit
       cat(paste0('This graph has ', x$dotplots, ' printed ', x$VertHorz, '\n',
-                 ifelse(length(x$ExtraArgs$main) > 0, 'with the title: ',
-                        'but has no title'), x$ExtraArgs$main, '\n'))
+                 .getGraphName(x), '\n'))
       if (!is.null(x$ExtraArgs$dlab) | !is.null(x$ExtraArgs$glab)) {
-        warning(
-            "Use of dlab or glab arguments is not advised. Use xlab and ylab instead.")
+        .OldCodeWarning(Old="dlab or glab arguments", New = "xlab and ylab ")
       } else {
         cat(paste0(ifelse(length(x$ExtraArgs$xlab) > 0, InQuotes(x$ExtraArgs$xlab), 'No label'),
                    ' appears on the x-axis.\n',
-                   ifelse(length(x$ExtraArgs$ylab) > 0, paste0('"', x$ExtraArgs$ylab, '"'),
+                   .ifelse(length(x$ExtraArgs$ylab) > 0, paste0('"', x$ExtraArgs$ylab, '"'),
                           'No label'), ' appears on the y-axis.\n'))
       }
       if (x$vertical) {
@@ -112,8 +127,8 @@ VI.dotplot =
 VI.histogram =
     function(x, Describe=FALSE, ...) {
       cat(paste0('This is a histogram, with the title: ',
-          ifelse(length(x$ExtraArgs$main) > 0, x$ExtraArgs$main, paste("Histogram of", x$xname)),
-          '\n', ifelse(length(x$ExtraArgs$xlab) > 0, InQuotes(x$ExtraArgs$xlab), InQuotes(x$xname)),
+                 .getGraphName(x, titlePreamble = "with the title:", noTitleMessage = "with no title"),
+          '\n', .ifelse(length(x$ExtraArgs$xlab) > 0, InQuotes(x$ExtraArgs$xlab), InQuotes(x$xname)),
           ' is marked on the x-axis.\n'))
       cat("Tick marks for the x-axis are at:", .GetAxisTicks(x$par$xaxp), "\n")
       cat('There are a total of', sum(x$counts),
@@ -270,17 +285,17 @@ VI.qcc = function (x, ...)
 {
 TypeText = paste("This control chart is a", x$type, "chart.")
 SubgroupSizesConst = diff(range(x$sizes))==0 
-PointText = paste("Data for", length(x$statistics), "subgroups of", ifelse(SubgroupSizesConst, "equal", "varying"), "size are marked.")
-CenterText = ifelse(length(x$center)==1,
+PointText = paste("Data for", length(x$statistics), "subgroups of", .ifelse(SubgroupSizesConst, "equal", "varying"), "size are marked.")
+CenterText = .ifelse(length(x$center)==1,
     paste0("The center line is marked at ", signif(x$center,4),  "."),
     "There is more than one center line.")
-CLText = ifelse(length(x$limits)==2,
+CLText = .ifelse(length(x$limits)==2,
    paste0("The LCL is at ", signif(x$limits[,1], 4), " and the UCL is at ", signif(x$limits[,2],4), "."),
     "There are more than one set of control limits.")
 NoBL = length(x$violations$beyond.limits)
-BLText = paste("There",  ifelse(NoBL==1, "is", "are"), ifelse(NoBL==0, "no", NoBL), ifelse(NoBL==1, "point", "points"), "that breach the control limits.")
+BLText = paste("There",  .ifelse(NoBL==1, "is", "are"), .ifelse(NoBL==0, "no", NoBL), .ifelse(NoBL==1, "point", "points"), "that breach the control limits.")
 NoVR = length(x$violations$violating.runs) 
-VRText = paste0("There ", ifelse(NoVR==1, "is", "are"), " ", ifelse(NoVR==0, "no", NoVR), " violating run", ifelse(NoVR==1, "", "s"), ".")
+VRText = paste0("There ", .ifelse(NoVR==1, "is", "are"), " ", .ifelse(NoVR==0, "no", NoVR), " violating run", .ifelse(NoVR==1, "", "s"), ".")
 
 Out = c(TypeText, PointText, CenterText, CLText, BLText, VRText)
 class(Out) = "VI"
