@@ -1,4 +1,9 @@
 
+
+.RunWriteRExecutable = function(file=NULL){
+            shell(paste0(Sys.which("WriteR"), .ifelse(is.null(file), "", file)), wait=FALSE)
+}
+
 .IsWriteRAvailable =
     function(){
       Success = FALSE
@@ -22,16 +27,16 @@ WriteR =
     function(file = NULL, math = c("webTeX", "MathJax")) {
       if (interactive()) {
         if (.Platform$OS.type == "windows") {
-          if (.IsWriteRAvailable()) {
+          if (.IsWriteRAvailable() | Sys.which("WriteR") != "") {
             if (!is.null(file)) {
               if (!file.exists(file)) {
-                #cat("Starting new file\n", file = file)
+                .FileCreated(file=file, where="in the current directory.") 
                 file.copy(system.file("Templates/simpleYAMLHeader.Rmd", package="BrailleR"), file)
               }
             }
             shell(paste0('"', file.path(system.file(
                             "Python/WriteR/WriteR.pyw", package = "BrailleR")), '" ',
-                        ifelse(is.null(file), "", file)), wait=FALSE)
+                        .ifelse(is.null(file), "", file)), wait=FALSE)
           } else {
             .NeedsWX()
             .InstallPython()
